@@ -53,10 +53,9 @@
 #' @importFrom Matrix rowMeans
 #' @importFrom scuttle summarizeAssayByGroup
 plotGroupedHeatmap <- function(object, features, group, block = NULL, 
-    columns=NULL, exprs_values = "logcounts", center = FALSE, scale = FALSE, 
-    zlim = NULL, colour = color, swap_rownames=NULL, symmetric=NULL, 
-    color = NULL, ...) 
-{
+    columns=NULL, exprs_values = "logcounts", center = FALSE, scale = FALSE,
+    zlim = NULL, colour = color, swap_rownames = NULL, color = NULL, assay.type=exprs_values, ...) {
+
     # Setting names, otherwise the downstream colouring fails.
     if (is.null(colnames(object))) { 
         colnames(object) <- seq_len(ncol(object)) 
@@ -66,7 +65,7 @@ plotGroupedHeatmap <- function(object, features, group, block = NULL,
     object <- .swap_rownames(object, swap_rownames)
     # in case of numeric or logical features, converts to character or factor
     features <- .handle_features(features, object)
-    heat.vals <- assay(object, exprs_values)[as.character(features), , drop=FALSE]
+    heat.vals <- assay(object, assay.type)[as.character(features), , drop=FALSE]
     if (is.factor(features)) {
         heat.vals <- heat.vals[levels(features), , drop = FALSE]
     }
@@ -83,9 +82,14 @@ plotGroupedHeatmap <- function(object, features, group, block = NULL,
     if (!is.null(columns)) {
         ids <- ids[columns,,drop=FALSE]
     }
-    heat.se <- summarizeAssayByGroup(heat.vals, ids, statistic="mean")
-    heat.vals <- correctGroupSummary(assay(heat.se), group=heat.se$group, block=heat.se$group)
-    heatmap_scale <- .heatmap_scale(heat.vals, center=center, scale=scale, colour=colour, zlim=zlim, symmetric=symmetric)
+    heat.se <- summarizeAssayByGroup(heat.vals, ids, statistics="mean")
+    if (!is.null(block)) {
+        heat.se <- correctGroupSummary(assay(heat.se), group=heat.se$group, block=heat.se$block)
+    }
+    if (inherits(heat.se, "SummarizedExperiment")) {
+        heat.se <- assay(heat.se)
+    }
+    heatmap_scale <- .heatmap_scale(heat.se, center=center, scale=scale, colour=colour, zlim=zlim)
 
     # Creating the heatmap as specified.
     pheatmap::pheatmap(heatmap_scale$x, color=heatmap_scale$colour, breaks=heatmap_scale$colour_breaks, ...) 
